searchNodes=[{"doc":"GenRetry provides utilities for retrying Elixir functions, with configurable delay and backoff characteristics. Summary Given a 0-arity function which raises an exception upon failure, retry/2 and retry_link/2 repeatedly executes the function until success is reached or the maximum number of retries has occurred. GenRetry.Task.async/2 and GenRetry.Task.Supervisor.async/3 provide drop-in replacements for Task.async/1 and Task.Supervisor.async/2 , respectively, adding retry capability. They return plain %Task{} structs, usable with any other function in the Task module. Examples my_background_function = fn -&gt; :ok = try_to_send_tps_reports ( ) end GenRetry . retry ( my_background_function , retries : 10 , delay : 10_000 ) my_future_function = fn -&gt; { :ok , val } = get_val_from_flaky_network_service ( ) val end t = GenRetry.Task . async ( my_future_function , retries : 3 ) my_val = Task . await ( t ) # may raise exception Installation Add GenRetry to your list of dependencies in mix.exs : def deps do [ { :gen_retry , &quot;~&gt; 1.4.0&quot; } ] end Ensure GenRetry is started before your application: def application do [ applications : [ :gen_retry ] ] end (Optional) Specify a custom logging module in your config.exs config :gen_retry , GenRetry.Logger , logger : MyApp.CustomLogger where MyApp.CustomLogger implements the GenRetry.Logger behavior. The default module is GenRetry.Utils if none is specified in a config. Options :retries , integer (default 1): Number of times to retry upon failure. Set to 0 to try exactly once; set to :infinity to retry forever. :delay , integer (default 1000): Number of milliseconds to wait between first failure and first retry. Subsequent retries use this value as a starting point for exponential backoff. :jitter , number (default 0): Proportion of current retry delay to randomly add to delay time. For example, given options delay: 1000, jitter: 0.1 , the first delay will be a random time between 1000 and 1100 milliseconds. Values under 0 will remove time rather than add it; beware of values under -1, which may result in nonsensical &quot;negative time delays&quot;. :exp_base , number (default 2): The base to use for exponentiation during exponential backoff. Set to 1 to disable backoff. Values less than 1 are not very useful. :respond_to , pid (ignored by GenRetry.Task.* ): The process ID to which a message should be sent upon completion. Successful exits send {:success, return_value, final_retry_state} ; unsuccessful exits send {:failure, error, stacktrace, final_retry_state} . :on_success , fn {result, final_retry_state} -&gt; nil end (default no-op): A function to run on success. The argument is a tuple containing the result and the final retry state. :on_failure , fn {exception, stacktrace, final_retry_state} -&gt; nil end (default no-op): A function to run on failure. The argument is a tuple containing the exception, stacktrace, and final retry state.","ref":"GenRetry.html","title":"GenRetry","type":"module"},{"doc":"Starts a retryable process linked to GenRetry.Supervisor , and returns its pid. fun should be a function that raises an exception upon failure; any other return value is treated as success.","ref":"GenRetry.html#retry/2","title":"GenRetry.retry/2","type":"function"},{"doc":"Starts a retryable process linked to the current process, and returns its pid. fun should be a function that raises an exception upon failure; any other return value is treated as success.","ref":"GenRetry.html#retry_link/2","title":"GenRetry.retry_link/2","type":"function"},{"doc":"","ref":"GenRetry.html#t:failure_msg/0","title":"GenRetry.failure_msg/0","type":"type"},{"doc":"","ref":"GenRetry.html#t:on_failure/0","title":"GenRetry.on_failure/0","type":"type"},{"doc":"","ref":"GenRetry.html#t:on_success/0","title":"GenRetry.on_success/0","type":"type"},{"doc":"","ref":"GenRetry.html#t:option/0","title":"GenRetry.option/0","type":"type"},{"doc":"","ref":"GenRetry.html#t:options/0","title":"GenRetry.options/0","type":"type"},{"doc":"","ref":"GenRetry.html#t:retryable_fun/0","title":"GenRetry.retryable_fun/0","type":"type"},{"doc":"","ref":"GenRetry.html#t:success_msg/0","title":"GenRetry.success_msg/0","type":"type"},{"doc":"","ref":"GenRetry.Logger.html","title":"GenRetry.Logger","type":"behaviour"},{"doc":"","ref":"GenRetry.Logger.html#c:log/1","title":"GenRetry.Logger.log/1","type":"callback"},{"doc":"Used to represent the state of a GenRetry invocation. This struct is part of the success or failure message to be optionally sent to another process, specified by opts[:respond_to] , upon completion. :function and :opts are the invocation arguments supplied by the user. :tries is the total number of attempts made before sending this message. :retry_at is either the timestamp of the last attempt, or 0 (if opts[:retries] == 0 ).","ref":"GenRetry.State.html","title":"GenRetry.State","type":"module"},{"doc":"","ref":"GenRetry.State.html#t:t/0","title":"GenRetry.State.t/0","type":"type"},{"doc":"Provides async/2 , which operates like Task.async/1 with retry capability.","ref":"GenRetry.Task.html","title":"GenRetry.Task","type":"module"},{"doc":"Works like Task.async , but with retry. Returns a regular %Task{} usable with the rest of the functions in Task . opts are GenRetry options. The :respond_to option is tolerated, but ignored.","ref":"GenRetry.Task.html#async/2","title":"GenRetry.Task.async/2","type":"function"},{"doc":"Provides async/3 , which operates like Task.Supervisor.async/2 with retry capability.","ref":"GenRetry.Task.Supervisor.html","title":"GenRetry.Task.Supervisor","type":"module"},{"doc":"Works like Task.Supervisor.async/2 , but with retry. Returns a regular %Task{} usable with the rest of the functions in Task . opts are GenRetry options. The :respond_to option is tolerated, but ignored.","ref":"GenRetry.Task.Supervisor.html#async/3","title":"GenRetry.Task.Supervisor.async/3","type":"function"},{"doc":"Works like Task.Supervisor.async_nolink/2 , but with retry. Returns a regular %Task{} usable with the rest of the functions in Task . opts are GenRetry options. The :respond_to option is tolerated, but ignored.","ref":"GenRetry.Task.Supervisor.html#async_nolink/3","title":"GenRetry.Task.Supervisor.async_nolink/3","type":"function"},{"doc":"","ref":"GenRetry.TestLogger.html","title":"GenRetry.TestLogger","type":"module"},{"doc":"","ref":"GenRetry.Utils.html","title":"GenRetry.Utils","type":"module"}]